<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>ActionPackData</name>
    <message>
        <location filename="../actions/actionpackdata/actionpackdata.h" line="90"/>
        <source>Data related actions</source>
        <translation>Actions liées aux données</translation>
    </message>
</context>
<context>
    <name>Actions::CopyFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="44"/>
        <source>Source file</source>
        <translation>Fichier source</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="45"/>
        <source>The file to copy</source>
        <translation>Le fichier à copier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="47"/>
        <source>Choose the file</source>
        <translation>Choisissez le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="48"/>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="55"/>
        <source>All files (*.*)</source>
        <translation>Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="51"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="52"/>
        <source>The destination file</source>
        <translation>Le fichier de destination</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="54"/>
        <source>Choose the destination file</source>
        <translation>Choisissez le fichier de destination</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="58"/>
        <source>Unable to read source file</source>
        <translation>Impossible de lire le fichier source</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="59"/>
        <source>Unable to write destination file</source>
        <translation>Impossible d&apos;écrire le fichier de destination</translation>
    </message>
</context>
<context>
    <name>Actions::CopyFileInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfileinstance.h" line="62"/>
        <source>Unable to read the source file &quot;%1&quot;</source>
        <translation>Impossible de lire de fichier source &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfileinstance.h" line="70"/>
        <source>Unable to write to &quot;%1&quot;</source>
        <translation>Impossible d&apos;écrire vers &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Actions::ReadBinaryFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="45"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="46"/>
        <source>The file to read from</source>
        <translation>Le fichier à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="48"/>
        <source>Choose the file</source>
        <translation>Choisissez le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="49"/>
        <source>All files (*.*)</source>
        <translation>Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="52"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="53"/>
        <source>The variable where to store the data</source>
        <translation>La variable où stocker les données</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="56"/>
        <source>Unable to read file</source>
        <translation>Impossible de lire le fichier</translation>
    </message>
</context>
<context>
    <name>Actions::ReadBinaryFileInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfileinstance.h" line="62"/>
        <source>Unable to read the file &quot;%1&quot;</source>
        <translation>Impossible de lire le fichier &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Actions::ReadClipboardDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readclipboarddefinition.h" line="45"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readclipboarddefinition.h" line="46"/>
        <source>The variable where to save the current clipboard value</source>
        <translation>La variable où enregistrer la valeur actuelle du presse-papiers</translation>
    </message>
</context>
<context>
    <name>Actions::ReadEnvironmentVariableDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="49"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="50"/>
        <source>The variable used to store the selected information from your system environment</source>
        <translation>La variable utilisée pour stocker l&apos;information sélectionnée à partir de votre environnement système</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="53"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="54"/>
        <source>The environment read mode</source>
        <translation>Le mode de lecture de l&apos;environnement</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="63"/>
        <source>Environment Variable</source>
        <translation>Variable d&apos;environnement</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="64"/>
        <source>The specific environment variable to read</source>
        <translation>La variable d&apos;environnement à lire</translation>
    </message>
</context>
<context>
    <name>Actions::ReadEnvironmentVariableInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentinstance.cpp" line="64"/>
        <source>The specified variable cannot be found in the system environment</source>
        <translation>La variable spécifiée ne peut pas être trouvée dans votre environnement système</translation>
    </message>
</context>
<context>
    <name>Actions::ReadIniFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="50"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="51"/>
        <source>The file to read from</source>
        <translation>Le fichier à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="53"/>
        <source>Choose the INI file</source>
        <translation>Choisissez le fichier INI</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="54"/>
        <source>INI files (*.ini);;All files (*.*)</source>
        <translation>Fichiers INI (*.ini);;Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="61"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="62"/>
        <source>The INI file read mode</source>
        <translation>Le mode de lecture du fichier INI</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="71"/>
        <source>Section</source>
        <translation>Section</translation>
    </message>
    <message>
        <source>The section name of the parameter</source>
        <translation type="obsolete">Le nom de section du paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="75"/>
        <source>Parameter</source>
        <translation>Paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="76"/>
        <source>The parameter name</source>
        <translation>Le nom du paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="57"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="58"/>
        <source>The variable where to store the data</source>
        <translation>La variable où stocker les données</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="72"/>
        <source>The parameter section</source>
        <translation>La section du paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="81"/>
        <source>Unable to read file</source>
        <translation>Impossible de lire le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="82"/>
        <source>Unable to find section</source>
        <translation>Impossible de trouver la section</translation>
    </message>
</context>
<context>
    <name>Actions::ReadIniFileInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifileinstance.cpp" line="46"/>
        <location filename="../actions/actionpackdata/actions/readinifileinstance.cpp" line="59"/>
        <source>Unable to read the file</source>
        <translation>Impossible de lire le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifileinstance.cpp" line="89"/>
        <source>Unable to find the section named &quot;%1&quot;</source>
        <translation>Impossible de trouver la section nommée &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifileinstance.cpp" line="100"/>
        <source>Unable to find the parameter named &quot;%1&quot;</source>
        <translation>Impossible de trouver le paramètre nommé &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Actions::ReadRegistryDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="46"/>
        <source>Key</source>
        <translation>Clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="47"/>
        <source>The registry key to read from</source>
        <translation>La clef de registre à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="52"/>
        <source>Subkey</source>
        <translation>Sous-clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="53"/>
        <source>The registry subkey to read from</source>
        <translation>La sous-clef du registre à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="56"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="57"/>
        <source>The value to read</source>
        <translation>La valeur à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="60"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="61"/>
        <source>The variable where to save the value read from the registry</source>
        <translation>La variable où enregistrer la valeur lue à partir du registre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="64"/>
        <source>Cannot find subKey</source>
        <translation>Impossible de trouver la sous-clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="65"/>
        <source>Cannot find value</source>
        <translation>Impossible de trouver la valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="66"/>
        <source>Invalid value type</source>
        <translation>Type de valeur incorrect</translation>
    </message>
</context>
<context>
    <name>Actions::ReadRegistryInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistryinstance.cpp" line="54"/>
        <source>Cannot find subKey &quot;%1&quot;</source>
        <translation>Impossible de trouver la sous-clef &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistryinstance.cpp" line="58"/>
        <source>Cannot find value &quot;%1&quot;</source>
        <translation>Impossible de trouver la valeur &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistryinstance.cpp" line="62"/>
        <source>Invalid value type</source>
        <translation>Type de valeur incorrect</translation>
    </message>
</context>
<context>
    <name>Actions::ReadTextFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="50"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="51"/>
        <source>The file you want to read</source>
        <translation>Le fichier à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="54"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="55"/>
        <source>The variable where to save the text read from the file</source>
        <translation>La variable où enregistrer le texte lu à partir du fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="58"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="59"/>
        <source>The file read mode</source>
        <translation>Le mode de lecture du fichier</translation>
    </message>
    <message>
        <source>Selection mode</source>
        <translation type="obsolete">Mode de sélection</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="68"/>
        <source>First line</source>
        <translation>Première ligne</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="69"/>
        <source>The line where to start reading the file</source>
        <translation>Line à partir de laquelle lire le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="74"/>
        <source>Last line</source>
        <translation>Dernière ligne</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="75"/>
        <source>The line where to stop reading the file</source>
        <translation>La ligne où arrêter de lire le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="82"/>
        <source>Cannot read file</source>
        <translation>Impossible de lire le fichier</translation>
    </message>
</context>
<context>
    <name>Actions::ReadTextFileInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfileinstance.cpp" line="50"/>
        <source>Invalid first line value : %1</source>
        <translation>Valeur de première ligne incorrecte : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfileinstance.cpp" line="57"/>
        <source>Invalid last line value : %1</source>
        <translation>Valeur de dernière ligne incorrecte : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfileinstance.cpp" line="64"/>
        <source>The first line has to be smaller than the last line</source>
        <translation>La première ligne doit être plus petite que la dernière</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfileinstance.cpp" line="73"/>
        <source>Cannot open file</source>
        <translation>Impossible d&apos;ouvrir le fichier</translation>
    </message>
</context>
<context>
    <name>Actions::SendMailDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="50"/>
        <source>Server name</source>
        <translation>Nom du serveur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="51"/>
        <source>The name or IP of the SMTP server to use
Example: mail.example.com</source>
        <translation>Le nom ou l&apos;adresse IP du serveur SMTP à utiliser
Exemple : mail.example.com</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="54"/>
        <source>Secure connection</source>
        <translation>Connexion sécurisée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="55"/>
        <source>Secure (encrypted) connection to the server</source>
        <translation>Utiliser une connexion sécurisée (chiffrée) vers le serveur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="59"/>
        <source>User name</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="60"/>
        <source>The user (or login) name to use
Many SMTP servers use the e-mail address as user name</source>
        <translation>Le nom d&apos;utilisateur (ou nom de login) à utiliser
De nombreux serveurs SMTP utilisent l&apos;adresse e-mail comme nom d&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="63"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="64"/>
        <source>The password to use</source>
        <translation>Le mot de passe à utiliser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="67"/>
        <source>Sender</source>
        <translation>Expéditeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="68"/>
        <source>The sender&apos;s e-mail address</source>
        <translation>L&apos;adresse e-mail de l&apos;expéditeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="71"/>
        <source>Receivers</source>
        <translation>Destinataires</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="72"/>
        <source>The receiver&apos;s e-mail address
Can contain multiple receivers separated with a comma</source>
        <translation>L&apos;adresse e-mail du destinataire
Peut contenir plusieurs destinataires séparés par une virgule</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="75"/>
        <source>Subject</source>
        <translation>Sujet</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="76"/>
        <source>The e-mail&apos;s subject</source>
        <translation>Le sujet de l&apos;e-mail</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="79"/>
        <source>Body</source>
        <translation>Contenu</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="80"/>
        <source>The e-mail&apos;s body</source>
        <translation>Le contenu de l&apos;e-mail</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="83"/>
        <source>Attachment name</source>
        <translation>Nom de la pièce jointe</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="84"/>
        <source>The attachment name, an empty name means that there is no attachment</source>
        <translation>Le nom de la pièce jointe, pas de pièce jointe si vide</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="87"/>
        <source>Attachment data</source>
        <translation>Données de la pièce jointe</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="88"/>
        <source>The data to attach to the e-mail</source>
        <translation>Les données de la pièce jointe à attacher à l&apos;e-mail</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="91"/>
        <source>Attachment content type</source>
        <translation>Type de contenu de la pièce jointe</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="92"/>
        <source>The MIME content type of the attachment
If left empty, Actiona will try to deduce it from the data type</source>
        <translation>Le type de contenu MIME de la pièce jointe
Si laissé vide, Actiona va tenter de le déduire à partir du type de données</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="97"/>
        <source>Carbon copy (Cc)</source>
        <translation>Copie à</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="98"/>
        <source>The carbon copy receiver&apos;s e-mail address
Can contain multiple receivers separated with a comma</source>
        <translation>L&apos;adresse e-mail du destinataire en copie
Peut contenir plusieurs destinataires séparés par une virgule</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="101"/>
        <source>Blind carbon copy (Bcc)</source>
        <translation>Copie cachée à</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="102"/>
        <source>The blind carbon copy receiver&apos;s e-mail address
Can contain multiple receivers separated with a comma</source>
        <translation>L&apos;adresse e-mail du destinataire en copie cachée
Peut contenir plusieurs destinataires séparés par une virgule</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="105"/>
        <source>Server port</source>
        <translation>Port du serveur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="106"/>
        <source>The server port</source>
        <translation>Le port du serveur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="110"/>
        <source>Default port</source>
        <translation>Port par défaut</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="113"/>
        <source>Extra headers</source>
        <translation>Entêtes supplémentaires</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="114"/>
        <source>Extra headers to add to the e-mail
Should contain one header per line</source>
        <translation>Entêtes supplémentaires à ajouter à l&apos;e-mail
Doit contenir un entête par ligne</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="117"/>
        <source>Connection error</source>
        <translation>Erreur de connexion</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="118"/>
        <source>Error while sending e-mail</source>
        <translation>Erreur lors de l&apos;envoi de l&apos;e-mail</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="128"/>
        <source>Attachment</source>
        <translation>Pièce jointe</translation>
    </message>
</context>
<context>
    <name>Actions::SendMailInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="115"/>
        <source>Failed to auto detect the attachment content type</source>
        <translation>Impossible de détecter automatiquement le type de contenu de la pièce jointe</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="120"/>
        <source>server port</source>
        <translation>port du serveur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="163"/>
        <source>Failed to parse an extra header: &quot;%1&quot; has to be in the form &quot;name: value&quot;</source>
        <translation>Impossible d&apos;analyser l&apos;entête supplémentaire : &quot;%1&quot; doit être sous la forme &quot;nom: valeur&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="175"/>
        <source>Invalid attachment data</source>
        <translation>Données de pièce jointe invalides</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="197"/>
        <source>Unknown image type; supported types are PNG and JPG</source>
        <translation>Type d&apos;image inconnu; les types supportés sont PNG et JPG</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="207"/>
        <source>Invalid image data</source>
        <translation>Données d&apos;image invalides</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="245"/>
        <source>Sending e-mail</source>
        <translation>Envoi de l&apos;e-mail</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="246"/>
        <source>Connecting...</source>
        <translation>Connexion...</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="260"/>
        <source>Connection failed: %1</source>
        <translation>Impossible de se connecter : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="267"/>
        <source>Encryption failed: %1</source>
        <translation>Impossible de chiffrer la connexion : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="274"/>
        <source>Authentication failed: %1</source>
        <translation>L&apos;authentification a échouée : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="280"/>
        <source>Sending e-mail...</source>
        <translation>Envoi de l&apos;e-mail...</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="289"/>
        <source>Sender %1 has been rejected: %2</source>
        <translation>L&apos;expéditeur %1 a été rejeté : %2</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="298"/>
        <source>Recipient %1 has been rejected: %2</source>
        <translation>Le destinataire %1 a été rejeté : %2</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="312"/>
        <source>No recipients</source>
        <translation>Pas de destinataires</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="315"/>
        <source>Command unrecognized</source>
        <translation>Commande inconnue</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="318"/>
        <source>Syntax error</source>
        <translation>Erreur de syntaxe</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="321"/>
        <source>Command not implemented</source>
        <translation>Commande non implémentée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="324"/>
        <source>Bad sequence</source>
        <translation>Mauvaise séquence</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="327"/>
        <source>Parameter not implemented</source>
        <translation>Paramètre non implémenté</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="330"/>
        <source>Mailbox unavailable</source>
        <translation>Boîte de réception indisponible</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="333"/>
        <source>User not local</source>
        <translation>Utilisateur non local</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="336"/>
        <source>Message is too large</source>
        <translation>Le message est trop grand</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="339"/>
        <source>Invalid mailbox name</source>
        <translation>Nom de boîte de réception invalide</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="342"/>
        <source>Transaction failed</source>
        <translation>Échec de la transaction</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="345"/>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="349"/>
        <source>Failed sending e-mail: %1 (%2)</source>
        <translation>Impossible d&apos;envoyer l&apos;e-mail : %1 (%2)</translation>
    </message>
</context>
<context>
    <name>Actions::WebDownloadDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="51"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="52"/>
        <source>The URL of the data to download</source>
        <translation>L&apos;URL des données à télécharger</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="55"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="56"/>
        <source>The destination where to write the downloaded data</source>
        <translation>La destination des données téléchargées</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="65"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="66"/>
        <source>The variable where to write the downloaded data</source>
        <translation>La variable où stocker les données téléchargées</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="75"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="76"/>
        <source>The file where to write the downloaded data</source>
        <translation>Le fichier où stocker les données téléchargées</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="78"/>
        <source>Choose the destination file</source>
        <translation>Choisissez le fichier de destination</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="79"/>
        <source>All files (*.*)</source>
        <translation>Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="84"/>
        <source>Show progress</source>
        <translation>Afficher la progression</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="85"/>
        <source>Should the download progress be shown</source>
        <translation>Affiche ou non la progression du téléchargement</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="89"/>
        <source>Cannot write to file</source>
        <translation>Impossible d&apos;écrire vers le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="90"/>
        <source>Download error</source>
        <translation>Erreur de téléchargement</translation>
    </message>
</context>
<context>
    <name>Actions::WebDownloadInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="70"/>
        <source>Invalid URL</source>
        <translation>URL invalide</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="80"/>
        <source>Cannot write to file</source>
        <translation>Impossible d&apos;écrire vers le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="92"/>
        <source>Downloading</source>
        <translation>Téléchargement</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="93"/>
        <source>Downloading...</source>
        <translation>Téléchargement...</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="129"/>
        <source>Download error: %1</source>
        <translation>Erreur de téléchargement : %1</translation>
    </message>
</context>
<context>
    <name>Actions::WriteBinaryFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="45"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="46"/>
        <source>The file to write to</source>
        <translation>Le fichier à écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="48"/>
        <source>Choose the file</source>
        <translation>Choisissez le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="49"/>
        <source>All files (*.*)</source>
        <translation>Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="52"/>
        <source>Data</source>
        <translation>Données</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="53"/>
        <source>The data to write to the file</source>
        <translation>Les données à écrire dans le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="56"/>
        <source>Unable to write to the file</source>
        <translation>Impossible d&apos;écrire vers le fichier</translation>
    </message>
</context>
<context>
    <name>Actions::WriteBinaryFileInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfileinstance.h" line="63"/>
        <source>Unable to write to the file &quot;%1&quot;</source>
        <translation>Impossible d&apos;écrire vers le fichier &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Actions::WriteClipboardDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writeclipboarddefinition.h" line="45"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeclipboarddefinition.h" line="46"/>
        <source>The new clipboard value</source>
        <translation>La nouvelle valeur du presse-papier</translation>
    </message>
</context>
<context>
    <name>Actions::WriteIniFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="45"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="46"/>
        <source>The file to create or edit</source>
        <translation>Le fichier à créer ou à éditer</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="48"/>
        <source>Choose the INI file</source>
        <translation>Choisissez le fichier INI</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="49"/>
        <source>INI files (*.ini);;All files (*.*)</source>
        <translation>Fichiers INI (*.ini);;Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="52"/>
        <source>Section</source>
        <translation>Section</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="53"/>
        <source>The section name of the parameter</source>
        <translation>Le nom de la section du paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="56"/>
        <source>Parameter</source>
        <translation>Paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="57"/>
        <source>The parameter name</source>
        <translation>Le nom du paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="60"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="61"/>
        <source>The new value</source>
        <translation>La nouvelle valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="64"/>
        <source>Unable to write file</source>
        <translation>Impossible d&apos;écrire vers le fichier</translation>
    </message>
</context>
<context>
    <name>Actions::WriteIniFileInstance</name>
    <message>
        <source>Unable to write to the file</source>
        <translation type="obsolete">Impossible d&apos;écrire vers le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifileinstance.h" line="86"/>
        <source>Unable to write to the file: the section name cannot be empty</source>
        <translation>Impossible d&apos;écrire le fichier : le nom de section ne peut être vide</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifileinstance.h" line="99"/>
        <source>Unable to write to the file: %1</source>
        <translation>Impossible d&apos;écrire le fichier : %1</translation>
    </message>
</context>
<context>
    <name>Actions::WriteRegistryDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="46"/>
        <source>Key</source>
        <translation>Clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="47"/>
        <source>The registry key to write to</source>
        <translation>La clef de registre à écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="52"/>
        <source>Subkey</source>
        <translation>Sous-clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="53"/>
        <source>The registry subkey to write to</source>
        <translation>La sous-clef de registre à écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="56"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="57"/>
        <source>The value to write to</source>
        <translation>La valeur où écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="60"/>
        <source>Data</source>
        <translation>Données</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="61"/>
        <source>The data to write</source>
        <translation>Les données à écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="64"/>
        <source>Cannot find subKey</source>
        <translation>Impossible de trouver la sous-clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="65"/>
        <source>Cannot write value</source>
        <translation>Impossible d&apos;écrire la valeur</translation>
    </message>
</context>
<context>
    <name>Actions::WriteRegistryInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistryinstance.cpp" line="47"/>
        <source>Cannot find subKey &quot;%1&quot;</source>
        <translation>Impossible de trouver la sous-clef &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistryinstance.cpp" line="51"/>
        <source>Cannot write value &quot;%1&quot;</source>
        <translation>Impossible d&apos;écrire la valeur &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Actions::WriteTextFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="48"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="49"/>
        <source>The file you want to write</source>
        <translation>Le fichier à écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="52"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="53"/>
        <source>The text to write to the file</source>
        <translation>Le texte à écrire vers le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="56"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="57"/>
        <source>The file write mode</source>
        <translation>Le mode d&apos;écriture du fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="62"/>
        <source>Cannot write file</source>
        <translation>Impossible d&apos;écrire le fichier</translation>
    </message>
</context>
<context>
    <name>Actions::WriteTextFileInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfileinstance.cpp" line="47"/>
        <source>Cannot open file</source>
        <translation>Impossible d&apos;ouvrir le fichier</translation>
    </message>
</context>
<context>
    <name>Code::Clipboard</name>
    <message>
        <location filename="../actions/actionpackdata/code/clipboard.cpp" line="113"/>
        <source>Selection mode is not supported by your operating system</source>
        <translation>Le mode sélection n&apos;est pas supporté par votre système d&apos;exploitation</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/clipboard.cpp" line="120"/>
        <source>Find buffer mode is not supported by your operating system</source>
        <translation>Le mode tampon de recherche n&apos;est pas supporté par votre système d&apos;exploitation</translation>
    </message>
</context>
<context>
    <name>Code::File</name>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="56"/>
        <location filename="../actions/actionpackdata/code/file.cpp" line="91"/>
        <location filename="../actions/actionpackdata/code/file.cpp" line="214"/>
        <source>Incorrect parameter count</source>
        <translation>Nombre de paramètres incorrect</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="119"/>
        <source>Unable to open file</source>
        <translation>Impossible d&apos;ouvrir le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="130"/>
        <location filename="../actions/actionpackdata/code/file.cpp" line="135"/>
        <location filename="../actions/actionpackdata/code/file.cpp" line="144"/>
        <source>Write failed</source>
        <translation>L&apos;écriture a échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="276"/>
        <location filename="../actions/actionpackdata/code/file.cpp" line="372"/>
        <source>Unable to create destination directory</source>
        <translation>Impossible de créer le dossier de destination</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="282"/>
        <location filename="../actions/actionpackdata/code/file.cpp" line="378"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>Le dossier de destination n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="297"/>
        <source>Copy failed</source>
        <translation>Copie échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="335"/>
        <source>Copy failed: %1</source>
        <translation>Copie échouée : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="341"/>
        <source>Copy failed: aborted</source>
        <translation>Copie échouée : annulée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="393"/>
        <source>Move/rename failed</source>
        <translation>Déplacement/renommage échoué</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="431"/>
        <source>Move failed: %1</source>
        <translation>Déplacement échoué : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="437"/>
        <source>Move failed: aborted</source>
        <translation>Déplacement échoué : annulé</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="486"/>
        <source>Rename failed: %1</source>
        <translation>Renommage échoué : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="492"/>
        <source>Rename failed: aborted</source>
        <translation>Renommage échoué : annulé</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="519"/>
        <source>Remove failed</source>
        <translation>Le suppression a échoué</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="551"/>
        <source>Remove failed: %1</source>
        <translation>Suppression échouée : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="557"/>
        <source>Remove failed: aborted</source>
        <translation>Suppression échouée : annulée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="578"/>
        <source>File not found</source>
        <translation>Impossible de trouver le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="580"/>
        <source>Path not found</source>
        <translation>Impossible de trouver le chemin</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="582"/>
        <source>Access denied</source>
        <translation>Accès refusé</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="584"/>
        <source>This file is used by another process</source>
        <translation>Ce fichier est utilisé par un autre processus</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="586"/>
        <source>The disk is full</source>
        <translation>Plus d&apos;espace disponible sur le disque</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="589"/>
        <source>The file already exists</source>
        <translation>Le fichier existe déjà</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="591"/>
        <source>Invalid name</source>
        <translation>Nom incorrect</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="593"/>
        <source>Canceled</source>
        <translation>Annulé</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="595"/>
        <source>Unknown error (%1)</source>
        <translation>Erreur inconnue (%1)</translation>
    </message>
</context>
<context>
    <name>Code::IniFile</name>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="60"/>
        <source>Cannot load the file</source>
        <translation>Impossible de charger le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="79"/>
        <source>Cannot save the file</source>
        <translation>Impossible d&apos;enregistrer le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="101"/>
        <source>Cannot find the section named &quot;%1&quot;</source>
        <translation>Impossible de trouver la section nommée &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="126"/>
        <source>Invalid section index</source>
        <translation>Index de section incorrect</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="143"/>
        <source>Cannot delete section named &quot;%1&quot;</source>
        <translation>Impossible de supprimer la section nommée &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="166"/>
        <source>Invalid key index</source>
        <translation>Index de clef incorrect</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="181"/>
        <source>Cannot find any key named &quot;%1&quot;</source>
        <translation>Impossible de trouver une-clef nommée &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="203"/>
        <source>Cannot delete key named &quot;%1&quot;</source>
        <translation>Impossible de supprimer la clef nommée &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Code::Mail</name>
    <message>
        <location filename="../actions/actionpackdata/code/mail.cpp" line="117"/>
        <source>Incorrect parameter type: not a MailMessage</source>
        <translation>Type de paramètre incorrect : pas un MailMessage</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/mail.cpp" line="126"/>
        <source>Cannot establish a connection to the server</source>
        <translation>Impossible d&apos;établir une connexion avec le serveur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/mail.cpp" line="135"/>
        <source>Cannot encrypt the connection</source>
        <translation>Impossible de chiffre la connexion</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/mail.cpp" line="144"/>
        <source>Cannot authenticate to the server</source>
        <translation>Impossible de s&apos;identifier auprès du serveur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/mail.cpp" line="153"/>
        <source>Wait for finished failed</source>
        <translation>Attente de fin échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/mail.cpp" line="162"/>
        <source>Wait for disconnected failed</source>
        <translation>Attente de déconnexion échouée</translation>
    </message>
</context>
<context>
    <name>Code::MailMessage</name>
    <message>
        <location filename="../actions/actionpackdata/code/mailmessage.cpp" line="85"/>
        <source>Incorrect parameter type: not a MailAttachment</source>
        <translation>Type de paramètre incorrect : pas un MailAttachment</translation>
    </message>
</context>
<context>
    <name>Code::Registry</name>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="59"/>
        <source>Unable to open the key</source>
        <translation>Impossible d&apos;ouvrir la clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="78"/>
        <source>Unable to create the key</source>
        <translation>Impossible de créer la clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="103"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="111"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="126"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="133"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="142"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="145"/>
        <source>Cannot set the value data</source>
        <translation>Impossible de changer les données de la valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="164"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="176"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="194"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="223"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="238"/>
        <source>Cannot find the value to read</source>
        <translation>Impossible de trouver la valeur à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="247"/>
        <source>Invalid value type</source>
        <translation>Type de valeur incorrect</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="267"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="309"/>
        <source>Unable to query informations about this key</source>
        <translation>Impossible de récupérer des informations à propos de cette clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="343"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="448"/>
        <source>Unable to delete the key</source>
        <translation>Impossible de supprimer la clef</translation>
    </message>
</context>
<context>
    <name>Code::Sql</name>
    <message>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="38"/>
        <source>Please specify the database driver that should be used</source>
        <translation>Merci de spécifier le pilote de base de données à utiliser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="105"/>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="112"/>
        <source>The requested database driver is not available</source>
        <translation>Ce pilote de base de données n&apos;est pas disponible</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="149"/>
        <source>Unable to establish a connection to the database</source>
        <translation>Impossible d&apos;établir une connexion vers la base de données</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="162"/>
        <source>Failed to prepare the query</source>
        <translation>Impossible de préparer la requête</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="196"/>
        <source>Failed to execute the query : %1</source>
        <translation>Impossible d&apos;exécuter la requête : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="207"/>
        <source>Cannot fetch the result of a non-select query</source>
        <translation>Impossible de récupérer le résultat d&apos;une requête non-select</translation>
    </message>
</context>
<context>
    <name>Code::Tcp</name>
    <message>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="94"/>
        <source>Cannot establish a connection to the host</source>
        <translation>Impossible d&apos;établir une connexion vers l&apos;hôte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="102"/>
        <source>Waiting for bytes written failed</source>
        <translation>Attente d&apos;écriture échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="110"/>
        <source>Waiting for ready read failed</source>
        <translation>Attente de lecture échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="118"/>
        <source>Waiting for disconnection failed</source>
        <translation>Attente de déconnexion échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="129"/>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="134"/>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="143"/>
        <source>Write failed</source>
        <translation>Écriture échouée</translation>
    </message>
</context>
<context>
    <name>Code::TcpServer</name>
    <message>
        <location filename="../actions/actionpackdata/code/tcpserver.cpp" line="59"/>
        <source>Unable to start listening</source>
        <translation>Impossible de démarrer l&apos;écoute</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/tcpserver.cpp" line="67"/>
        <source>Waiting for new connection failed</source>
        <translation>Attente de nouvelle connexion échouée</translation>
    </message>
    <message>
        <source>Waiting for bytes written failed</source>
        <translation type="obsolete">Attente d&apos;écriture échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/tcpserver.cpp" line="77"/>
        <source>There is no pending connection</source>
        <translation>Il n&apos;y a pas de connexion en attente</translation>
    </message>
</context>
<context>
    <name>Code::Udp</name>
    <message>
        <location filename="../actions/actionpackdata/code/udp.cpp" line="75"/>
        <source>Cannot establish a connection to the host</source>
        <translation>Impossible d&apos;établir une connexion vers l&apos;hôte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/udp.cpp" line="83"/>
        <source>Waiting for ready read failed</source>
        <translation>Attente de lecture échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/udp.cpp" line="94"/>
        <location filename="../actions/actionpackdata/code/udp.cpp" line="99"/>
        <location filename="../actions/actionpackdata/code/udp.cpp" line="108"/>
        <source>Write failed</source>
        <translation>Écriture échouée</translation>
    </message>
</context>
<context>
    <name>Code::Web</name>
    <message>
        <location filename="../actions/actionpackdata/code/web.cpp" line="95"/>
        <source>Unable to open the destination file</source>
        <translation>Impossible d&apos;écrire le fichier de destination</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="62"/>
        <source>Copy file</source>
        <translation>Copier fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="65"/>
        <source>Copy a file</source>
        <translation>Copie un fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="59"/>
        <source>Read binary file</source>
        <translation>Lire fichier binaire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="62"/>
        <source>Read a binary file</source>
        <translation>Lire un fichier binaire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readclipboarddefinition.h" line="50"/>
        <source>Read clipboard</source>
        <translation>Lire presse-papier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readclipboarddefinition.h" line="53"/>
        <source>Read the clipboard contents</source>
        <translation>Lit le contenu du presse-papier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="85"/>
        <source>Read INI file</source>
        <translation>Lire fichier INI</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="88"/>
        <source>Read one or all the entries in an INI file</source>
        <translation>Lire une ou plusieurs entrées d&apos;un fichier INI</translation>
    </message>
    <message>
        <source>Read an entry in an INI file</source>
        <translation type="obsolete">Lire une entrée dans un fichier INI</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="69"/>
        <source>Read registry</source>
        <translation>Lire registre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="72"/>
        <source>Read an entry from the registry</source>
        <translation>Lire une entrée de la base registre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="85"/>
        <source>Read text file</source>
        <translation>Lire fichier texte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="88"/>
        <source>Read a plain text file</source>
        <translation>Lire un fichier texte</translation>
    </message>
    <message>
        <source>Read the entire file</source>
        <translation type="obsolete">Lire le fichier entier</translation>
    </message>
    <message>
        <source>Read only a selection</source>
        <translation type="obsolete">Lire une sélection</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="59"/>
        <source>Write binary file</source>
        <translation>Écrire fichier binaire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="62"/>
        <source>Write to a binary file</source>
        <translation>Écrire vers un fichier binaire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeclipboarddefinition.h" line="50"/>
        <source>Write clipboard</source>
        <translation>Écrire presse-papier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeclipboarddefinition.h" line="53"/>
        <source>Set the clipboard contents</source>
        <translation>Change le contenu du presse-papier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="67"/>
        <source>Write INI file</source>
        <translation>Écrire fichier INI</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="70"/>
        <source>Write an entry in an INI file</source>
        <translation>Écrire une entrée dans un fichier INI</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="68"/>
        <source>Write registry</source>
        <translation>Écrire registre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="71"/>
        <source>Writes an entry to the registry</source>
        <translation>Écrire une entrée dans la base de registres</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="65"/>
        <source>Write text file</source>
        <translation>Écrire fichier texte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="68"/>
        <source>Write a plain text file</source>
        <translation>Écrire vers un fichier texte</translation>
    </message>
    <message>
        <source>Overwrite any content</source>
        <translation type="obsolete">Écraser tout contenu</translation>
    </message>
    <message>
        <source>Append to the end</source>
        <translation type="obsolete">Ajouter à la fin</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="93"/>
        <source>Web download</source>
        <translation>Téléchargement Web</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="96"/>
        <source>Downloads data from the Web</source>
        <translation>Télécharge des données à partir du Web</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="70"/>
        <source>Read environment variable</source>
        <translation>Lire variable d&apos;environnement</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="73"/>
        <source>Read a single or multiple environment variables</source>
        <translation>Lit une ou plusieurs variables d&apos;environnement</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="121"/>
        <source>Send e-mail</source>
        <translation>Envoi d&apos;e-mail</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmaildefinition.h" line="124"/>
        <source>Sends an e-mail</source>
        <translation>Envoie un e-mail</translation>
    </message>
</context>
<context>
    <name>ReadEnvironmentVariableInstance::modes</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentinstance.cpp" line="33"/>
        <source>Read all</source>
        <translation>Tout lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentinstance.cpp" line="33"/>
        <source>Read one</source>
        <translation>N&apos;en lire qu&apos;une</translation>
    </message>
</context>
<context>
    <name>ReadIniFileInstance::modes</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifileinstance.cpp" line="31"/>
        <source>Read a single parameter</source>
        <translation>Lire un seul paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifileinstance.cpp" line="31"/>
        <source>Read the entire file</source>
        <translation>Lire le fichier complet</translation>
    </message>
</context>
<context>
    <name>ReadTextFileInstance::modes</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfileinstance.cpp" line="30"/>
        <source>Read the entire file</source>
        <translation>Lire le fichier entier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfileinstance.cpp" line="30"/>
        <source>Read only a selection</source>
        <translation>Lire une sélection</translation>
    </message>
</context>
<context>
    <name>SendMailInstance::attachmentContentTypes</name>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="41"/>
        <source>Auto detect</source>
        <translation>Détection automatique</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="42"/>
        <source>Binary</source>
        <translation>Binaire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="43"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="44"/>
        <source>Jpg image</source>
        <translation>Image Jpg</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/sendmailinstance.cpp" line="45"/>
        <source>Png image</source>
        <translation>Image Png</translation>
    </message>
</context>
<context>
    <name>WebDownloadInstance::destinations</name>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="32"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="33"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
</context>
<context>
    <name>WriteTextFileInstance::modes</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfileinstance.cpp" line="30"/>
        <source>Overwrite any content</source>
        <translation>Écraser tout contenu</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfileinstance.cpp" line="30"/>
        <source>Append to the end</source>
        <translation>Ajouter à la fin</translation>
    </message>
</context>
</TS>
